==> sox_ng-14.4.4.tar.gz: sox_ng-14.4.4/wiki/Accounting.md <==
# Accounting

> *Careful accounts are a sine qua non for any organisation.<BR>Without them it falls into disrepute.<BR>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&mdash; Gandhi*

## Transactions

| When  | Who | What | How much |
| ----  | --- | ---- | -------: |
| 2024-10-16 | [martinwguy](https://codeberg.org/martinwguy) | Paid sox_ng's annual subscription to codeberg.org | €48.00 |
| 2024-09-02 | [martinwguy](https://codeberg.org/martinwguy) | Paid sox_ng's annual subscription to fastmail.com | £54.00 |
| 2024-08-01 | [martinwguy](https://codeberg.org/martinwguy) | Paid sox_ng's annual subscription to proton.me | €47.88 |
| 2024-06-13 | [martinwguy](https://codeberg.org/martinwguy) | Paid sox_ng's annual subscription to sourcehut.org | $50.00 |

## Donations

Poke one of the titles or scan one of the QR codes to make a donation via stripe.com

| [Euros](https://donate.stripe.com/aEU2bz10FcPR1qg5kk) | [Sterling](https://donate.stripe.com/9AQdUh8t78zBed24gh) | [US dollars](https://donate.stripe.com/3cs4jH10FdTVc4UbIK)
| :---: | :------: | :-----: |
|![QR code for donations in euro](images/Stripe-donate-qrcode-EUR.png)|![QR code for donations in sterling](images/Stripe-donate-qrcode-GBP.png)|![QR code for donations in US dollars](images/Stripe-donate-qrcode-USD.png)|

If you have an account on Stripe, you can [email SoX_ng](mailto:sox_ng@fastmail.com) to be added as a "team member" and view SoX_ng's transactions there. You don't have to make a donation for this.

You can also make [personal donations to martinwguy](http://martinwguy.net/donate.html)

## See also

* [Bounties](Bounties)

==> sox_ng-14.5.1.1.tar.gz: sox_ng-14.5.1.1/wiki/Accounting.md <==
# Accounting

> *Careful accounts are a sine qua non for any organisation.<BR>Without them it falls into disrepute.<BR>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&mdash; Gandhi*

## Transactions

| When  | Who | What | How much |
| ----  | --- | ---- | -------: |
| 2025-03-05 | [prof-spock](https://codeberg.org/prof-spock) | Donation | £80.59 |
| 2024-10-16 | [martinwguy](https://codeberg.org/martinwguy) | Paid sox_ng's annual subscription to codeberg.org | €48.00 |
| 2024-09-02 | [martinwguy](https://codeberg.org/martinwguy) | Paid sox_ng's annual subscription to fastmail.com | £54.00 |
| 2024-08-01 | [martinwguy](https://codeberg.org/martinwguy) | Paid sox_ng's annual subscription to proton.me | €47.88 |
| 2024-06-13 | [martinwguy](https://codeberg.org/martinwguy) | Paid sox_ng's annual subscription to sourcehut.org | $50.00 |

## Donations

Poke one of the titles or scan one of the QR codes to make a donation via stripe.com

| [Euros](https://donate.stripe.com/aEU2bz10FcPR1qg5kk) | [Sterling](https://donate.stripe.com/9AQdUh8t78zBed24gh) | [US dollars](https://donate.stripe.com/3cs4jH10FdTVc4UbIK)
| :---: | :------: | :-----: |
|![QR code for donations in euro](images/Stripe-donate-qrcode-EUR.png)|![QR code for donations in sterling](images/Stripe-donate-qrcode-GBP.png)|![QR code for donations in US dollars](images/Stripe-donate-qrcode-USD.png)|

If you have an account on Stripe, you can
[email SoX_ng](mailto:sox_ng@fastmail.com) to be added as a "team member"
and view SoX_ng's transactions there.
You don't have to make a donation for this.

You can also make [a personal donation to martinwguy](http://martinwguy.net/donate.html) to offset the costs
or raise a [Bounty](Bounties) for a specific issue to be resolved.
